@@ -2,6 +2,15 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
+    "%s has published the calendar »%s«" : "%s avaldas kalendri »%s«",
+    "Hello," : "Tere,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
+    "Open »%s«" : "Ava »%s«",
+    "Cheers!" : "Tervist!",
+    "Recipient" : "Saaja",
+    "Too many redirects. Aborting ..." : "Liiga palju ümbersuunamisi. Katkestamine ...",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Kaugserver ei andnud juurdepääsu kalendrile (HTTP {%s} viga)",
+    "Error connecting to remote server" : "Kaugserveriga ühendumise tõrge",
     "Individual" : "Individuaalne",
     "Group" : "Grupp",
     "Resource" : "Ressurss",
@@ -9,10 +18,13 @@ OC.L10N.register(
     "Unknown" : "Tundmatu",
     "Required" : "Kohustuslik",
     "Optional" : "Valikuline",
-    "Does not attend" : "Ei võta soa",
+    "Does not attend" : "Ei võta osa",
     "Please create a calendar first." : "Palun loo esmalt kalender.",
     "New event" : "Uus sündmus",
+    "CalDAV address for clients" : "CalDAV aadress klientidele",
+    "Email has been sent." : "E-kiri on saadetud.",
     "group" : "grupp",
+    "Details" : "Üksikasjad",
     "Attendees" : "Osalejad",
     "Reminders" : "Meelespead",
     "Repeating" : "Kordamine",
@@ -21,8 +33,9 @@ OC.L10N.register(
     "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
     "Confirmed" : "Kinnitatud",
     "Cancelled" : "Tühistatud",
-    "Please add a title!" : "Palu lisa pealkiri!",
-    "Please select a calendar!" : "Palun vali kalender!",
+    "Please add a title." : "Palun lisa pealkiri.",
+    "Please select a calendar." : "Palun vali kalender.",
+    "The event can not end before it starts." : "Sündmus ei saa lõppeda enne, kui see algab",
     "Global" : "Üldine",
     "None" : "Pole",
     "Every day" : "Iga päev",
@@ -40,8 +53,7 @@ OC.L10N.register(
     "2 hours before" : "2 tundi enne",
     "Custom" : "Kohandatud",
     "Audio" : "Helid",
-    "E Mail" : "E-post",
-    "Pop up" : "Hüpikaken",
+    "Pop-up" : "Hüpikaken",
     "sec" : "sek",
     "min" : "min",
     "hours" : "tundi",
@@ -55,11 +67,11 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Osaliselt imporditud, 1 ebaõnnestus",
     "Partially imported, {n} failures" : "Osaliselt imporditud, {n} ebaõnnestus",
     "Audio alarm" : "Helialarm",
-    "Pop-up" : "Hüpikaken",
-    "E-Mail" : "E-post",
     "{type} at {time}" : "{type} kell {time}",
     "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
     "Title of the Event" : "Sündmuse pealkiri",
+    "Starts" : "Algab",
+    "Ends" : "Lõpeb",
     "All day Event" : "Kogu päeva sündmus",
     "Delete" : "Kustuta",
     "Cancel" : "Loobu",
@@ -69,21 +81,34 @@ OC.L10N.register(
     "Close" : "Sulge",
     "Location" : "Asukoht",
     "Description" : "Kirjeldus",
+    "Event status" : "Sündmuse staatus",
+    "Visibility when sharing" : "Nähtavus jagamisel",
     "Export" : "Ekspordi",
     "Day" : "Päev",
     "Week" : "Nädal",
     "Month" : "Kuu",
     "Today" : "Täna",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Mõned sündmused selles kalendris on katki. Palun kontrolli JS konsooli, et rohkem infot saada.",
     "Share Calendar" : "Jaga kalendrit",
     "Shared" : "Jagatud",
     "More" : "Rohkem",
     "Edit" : "Muuda",
     "Link" : "Link",
+    "iCal link" : "iCal link",
     "Download" : "Lae alla",
+    "Share with users or groups" : "Jaga kasutajate või gruppidega",
     "can edit" : "saab muuta",
+    "Share link" : "Jaga link",
+    "Public access" : "Avalik ligipääs",
+    "Email link to person" : "Saada link e-postiga",
+    "Send" : "Saada",
     "New Calendar" : "Uus kalender",
     "Name" : "Nimi",
     "New Subscription" : "Uus tellimus",
+    "Go back" : "Mine tagasi",
+    "Go forward" : "Mine edasi",
+    "Calendar does not exist" : "Kalendrit pole olemas",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Võibolla said vale lingi või kalendri jagamine lõpetati?",
     "Edit event" : "Muuda sündmust",
     "Delete Event" : "Kustuta sündmus",
     "Save Event" : "Salvesta sündmus",
@@ -94,6 +119,7 @@ OC.L10N.register(
     "Repeat" : "Korda",
     "times every" : "korda iga",
     "Add" : "Lisa",
+    "Email address of attendee" : "Osaleja e-posti aadress",
     "from" : "alates",
     "to" : "kuni",
     "Reset repeating rule" : "Nulli kordamise reegel",
@@ -104,7 +130,9 @@ OC.L10N.register(
     "Import canceled" : "Importimine on tühistatud",
     "Analyzing calendar" : "Kalendri analüüsimine",
     "New calendar" : "Uus kalender",
+    "File is empty" : "Fail on tühi",
     "Import scheduled" : "Importimine on ajastatud",
+    "Show week numbers" : "Näita nädalanumberid",
     "Import calendar" : "Impordi kalender",
     "No Calendars selected for import" : "Pole valitud kalendreid, mida importida",
     "Primary CalDAV address" : "Primaarne CalDAV aadress",
