@@ -2,7 +2,9 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendar",
-    "%s has published the calendar \"%s\"" : "%s a publicat calendarul \"%s\"",
+    "Hello," : "Salut,",
+    "Cheers!" : "Noroc!",
+    "Recipient" : "Destinatar",
     "Too many redirects. Aborting ..." : "Prea multe redirecționări. Se abandonează ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serverul de la distanță nu ne-a dat acces la calendar (eroare HTTP {%s})",
     "Error connecting to remote server" : "Eroare la conectarea la serverul de la distanță",
@@ -23,8 +25,8 @@ OC.L10N.register(
     "CalDAV address for clients" : "CalDAV adresa pentru clienți",
     "Error saving WebCal-calendar" : "Eroare la salvarea calendarului WebCal",
     "WebDAV address for subscriptions" : "WebDAV adresa pentru abonamente",
-    "EMail has been sent." : "Email-ul a fost trimis.",
-    "There was an issue while sending your EMail." : "A apărut o problemă la trimiterea e-mailului.",
+    "Email has been sent." : "Email-ul a fost trimis",
+    "There was an issue while sending your email." : "A aparut o eroare la transmiterea email-ului.",
     "group" : "grup",
     "Details" : "Detalii",
     "Attendees" : "Participanți",
@@ -36,9 +38,7 @@ OC.L10N.register(
     "Confirmed" : "Confirmat",
     "Tentative" : "Tentativă",
     "Cancelled" : "Anulat",
-    "Please add a title!" : "Adaugă un titlu!",
-    "Please select a calendar!" : "Alege un calendar!",
-    "The event ends before it starts!" : "Evenimentul se termină înainte de a începe!",
+    "Please add a title." : "Adaugati un titlu.",
     "Global" : "Global",
     "None" : "Niciuna",
     "Every day" : "În fiecare zi",
@@ -57,8 +57,7 @@ OC.L10N.register(
     "2 hours before" : "cu 2 ore înainte",
     "Custom" : "Particularizat",
     "Audio" : "Audio",
-    "E Mail" : "Email",
-    "Pop up" : "Pop up",
+    "Pop-up" : "Pop up",
     "sec" : "sec",
     "min" : "min",
     "hours" : "ore",
@@ -73,8 +72,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Importat parțial, o eroare",
     "Partially imported, {n} failures" : "Importat parțial, {n} erori",
     "Audio alarm" : "Alarmă audio",
-    "Pop-up" : "Pop up",
-    "E-Mail" : "Email",
     "{type} {time} before the event starts" : "{type} {time} înainte de începerea evenimentului",
     "{type} {time} before the event ends" : "{type} {time} înainte de sfârșitul evenimentului",
     "{type} {time} after the event starts" : "{type} {time} după începerea evenimentului",
@@ -99,14 +96,10 @@ OC.L10N.register(
     "Visibility when sharing" : "Vizibilitate la partajare",
     "Export" : "Exportă",
     "%s has published the calendar %s" : "%s a publicat calendarul %s",
-    "Hello," : "Salut,",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Am vrut să vă anunțăm că %s  a publicat calendarul {boldstart}%s{boldend}.",
     "Click here to access it" : "Click aici pentru a accesa",
-    "Cheers!" : "Noroc!",
     "We wanted to inform you that %s has published the calendar %s." : "Am vrut să vă anunțăm că %s a publicat calendarul  %s.",
     "Click on the link below to access it" : "Faceți clic pe link-ul de mai jos pentru a accesa",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Din cauza unei erori \"upstream bug\", calendarul nu este în prezent în măsură să ofere suport pentru caracteristica \"asset pipeline\".",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Vă rugăm să contactați administratorul și solicitați să dezactiveze opțiunea de configurare \"asset-pipeline.enabled\".",
     "Day" : "Zi",
     "Week" : "Săptămâna",
     "Month" : "Luna",
@@ -130,6 +123,7 @@ OC.L10N.register(
     "New Subscription" : "Abonament nou",
     "Go back" : "Înapoi",
     "Go forward" : "Inainte",
+    "Calendar does not exist" : "Calendarul nu exista",
     "Edit event" : "Modifica eveniment",
     "Delete Event" : "Șterge evenimentul",
     "Save Event" : "Salvează evenimentul",
@@ -140,7 +134,6 @@ OC.L10N.register(
     "Repeat" : "Repetă",
     "times every" : "ori la fiecare",
     "Add" : "Adaugă",
-    "E-Mail address of attendee" : "Adresa email a participantului",
     "Please add your email address in the personal settings in order to add attendees." : "Vă rugăm să adăugați adresa de e-mail în setările personale pentru a adăuga participanți.",
     "from" : "de la",
     "to" : "către",
